# ![epi-spot](https://i.ibb.co/m9yS1yh/epispot-nightly.jpg)
![build](https://img.shields.io/badge/build-nightly-black)
![latest-release](https://shields.mitmproxy.org/pypi/v/epispot-nightly.svg?color=success)
[![Downloads](https://pepy.tech/badge/epispot-nightly)](https://pepy.tech/project/epispot-nightly)
![open-issues](https://img.shields.io/github/issues-search/epispot/epispot?color=red&label=Open%20Issues&query=is%3Aopen%20label%3Anightly)
<br><br>

Status: Waiting for PePy addition at 5:00 PST
**This is a nightly build of epispot. Releases may contain unstable code and issues are to be expected.
Additionally, code within this branch may be deprecated at any time.**

A tool for creating and testing epidemiological models faster than ever for the mathematical modeling of infectious 
diseases. An idea from https://github.com/henrifroese/infectious_disease_modelling.

**Epispot Nightly Build**
<br>

## Installation

Epispot nightly can _only_ be installed on pip at this time.
Install with:
```
pip install epispot-nightly
```
As a shorthand, use `import epispot as epi`.
Both packages cannot be used at the same time in the same file.

## Getting Started

Make sure you are already familiar with epispot. You can view the new functions and changes by using the built in python `help()` command.

## Latest Release Notes

None

# Stats
**GitHub Tests:** ![build-status](https://github.com/epispot/epispot/workflows/build/badge.svg?branch=nightly)
<br>**PyPi:** ![Downloads](https://pepy.tech/badge/epispot-nightly)

## Stay one step ahead
### And preview the latest features
Documentation can easily be accessed from function, class, and file docstrings.
Doc strings provide additional documentation on a certain function.
They can be accessed by the built-in Python `help()` command.
These strings are formatted in Github-flavored markdown.
Additionally, all files will have a 'STRUCTURE' label.
